@@ -9,14 +9,12 @@ import cairo
 import xml.dom.minidom as xmlparser
 import urllib2 
 import urllib
-PATH = "/apps/digghomewidget"
-CATGR = "/apps/digghomewidget/selected_category_int"
-NUM = "/apps/digghomewidget/number_of_stories"
-THMB = "/apps/digghomewidget/load_thumbnails"
-FIRST = "/apps/digghomewidget/first_run"
+PATH = "/apps/Maemo/digghomewidget"
+CATGR = "/apps/Maemo/digghomewidget/selected_category"
+NUM = "/apps/Maemo/digghomewidget/number_of_stories"
+THMB = "/apps/Maemo/digghomewidget/load_thumbnails"
+FIRST = "/apps/Maemo/digghomewidget/first_run"
 
-gobject.threads_init()
-#gtk.gdk.threads_init()
 
 class diggItem:
     def __init__(self, title, href, topic, diggs):
@@ -77,9 +75,11 @@ class diggLoader(gobject.GObject):
         if container != "":
             container = container.replace("&", "_")
             selected = "container/" + container + "/"
-        params = urllib.urlencode({"count":count, "appkey":"http://maemo.org/packages/view/digghomewidget/"})
+        params = urllib.urlencode({"count":count, "appkey":"2788b5db0429e01726e233ba59a7d287", "container":container})
         try:
-            url = "http://services.digg.com/stories/"+selected+hotness+"?%s" % params
+#            url = "http://services.digg.com/stories/"+selected+hotness+"?%s" % params
+            url = "http://services.digg.com/1.0/endpoint?method=story.getTop&%s" % params
+            print url
             f = urllib2.urlopen(url)
             data = f.read()
             self.read_and_return(data)
@@ -259,7 +259,13 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
             temp_cat = self.client.get_int(CATGR)
             temp_num = self.client.get_int(NUM)
             temp_check = self.client.get_bool(THMB)
-        except:
+            print "Loaded settings"
+            print temp_first
+            print temp_cat
+            print temp_num
+            print temp_check
+        except Exception, e:
+            print "Couldn't load settings ", e
             temp_first = False
             
         self.categories = []
@@ -381,7 +387,7 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
             self.loader.load_thumbnails = self.checkbox_active 
             self.client.set_bool(THMB, self.loader.load_thumbnails)
             self.category = categoryPicker.get_active() 
-            self.client.set_string(CATGR, self.categories[self.category])
+            self.client.set_int(CATGR, self.category)
             self.update_button(self)
         
     def pickerValueChanged(self, button, user_data=None):
@@ -392,6 +398,9 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
         list = sender.list
         if list != None:
             children = self.vbox.get_children()
+            print children
+            self.vbox.set_size_request(-1, self.count*(70+1)-1)
+            self.resize(300, 150+((self.count-1)*(70+1)))
             for child in children:
                 self.vbox.remove(child)
             if list != None:
@@ -400,7 +409,7 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
                     self.vbox.pack_start(button, False)
                     button.show()
             self.queue_draw()
-            self.client.set_string(CATGR, self.categories[self.category])
+            self.client.set_int(CATGR, self.category)
             title = self.categories[self.category]
             title = title.replace("_", "&")
             if title == "":
@@ -415,7 +424,7 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
 
     def show_settings(self, widget):
         dialog = gtk.Dialog()
-        dialog.set_transient_for(self)
+#        dialog.set_transient_for(self)
         dialog.set_title("Settings")
 #        settings.connect("value-changed", self.category_changed)
         thumbn_checkbox = hildon.CheckButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
@@ -443,15 +452,16 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
             cursize = self.get_size()
             self.count = num_itemsPicker.get_active() + 1 
             sep = oldcount - self.count
-            self.loader.load_thumbnails = self.checkbox_active 
+#            self.loader.load_thumbnails = self.checkbox_active 
             self.client.set_int(NUM, self.count)
-            self.client.set_bool(THMB, self.loader.load_thumbnails)
-            children = self.vbox.get_children()
-            for child in children:
-                self.vbox.remove(child)
-            self.vbox.set_size_request(-1, self.count*(70+1)-1)
-            self.set_size_request(300, cursize[1]-(sep*(70+1)))
-            self.resize(300, cursize[1]-(sep*(70+1)))
+#            self.client.set_bool(THMB, self.loader.load_thumbnails)
+#            children = self.vbox.get_children()
+#            for child in children:
+#                self.vbox.remove(child)
+#            self.vbox.set_size_request(-1, self.count*(70+1)-1)
+#            self.set_size_request(300, cursize[1]-(sep*(70+1)))
+            
+#            self.resize(300, cursize[1]-(sep*(70+1)))
             self.update_button(self)
 
     def checkbox_toggle(self, widget):
